==> webkitgtk-1.10.0.tar.xz: webkitgtk-1.10.0/Source/WebKit2/Shared/API/c/WKURLResponse.cpp <==
/*
 * Copyright (C) 2010 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "WKURLResponse.h"

#include "WKAPICast.h"
#include "WebURLResponse.h"
#include <WebCore/KURL.h>

using namespace WebKit;

WKTypeID WKURLResponseGetTypeID()
{
    return toAPI(WebURLResponse::APIType);
}

WKURLRef WKURLResponseCopyURL(WKURLResponseRef responseRef)
{
    return toCopiedURLAPI(toImpl(responseRef)->resourceResponse().url());
}

WKStringRef WKURLResponseCopyMIMEType(WKURLResponseRef responseRef)
{
    return toCopiedAPI(toImpl(responseRef)->resourceResponse().mimeType());
}

int32_t WKURLResponseHTTPStatusCode(WKURLResponseRef responseRef)
{
    return toImpl(responseRef)->resourceResponse().httpStatusCode();
}

==> webkitgtk_2.3.2.orig.tar.xz: webkitgtk-2.3.2/Source/WebKit2/Shared/API/c/WKURLResponse.cpp <==
/*
 * Copyright (C) 2010 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "WKURLResponse.h"

#include "WKAPICast.h"
#include "WebURLResponse.h"
#include <WebCore/URL.h>

using namespace WebKit;

WKTypeID WKURLResponseGetTypeID()
{
    return toAPI(WebURLResponse::APIType);
}

WKURLRef WKURLResponseCopyURL(WKURLResponseRef responseRef)
{
    return toCopiedURLAPI(toImpl(responseRef)->resourceResponse().url());
}

WKStringRef WKURLResponseCopyMIMEType(WKURLResponseRef responseRef)
{
    return toCopiedAPI(toImpl(responseRef)->resourceResponse().mimeType());
}

int32_t WKURLResponseHTTPStatusCode(WKURLResponseRef responseRef)
{
    return toImpl(responseRef)->resourceResponse().httpStatusCode();
}

WKStringRef WKURLResponseCopySuggestedFilename(WKURLResponseRef responseRef)
{
    return toCopiedAPI(toImpl(responseRef)->resourceResponse().suggestedFilename());
}

bool WKURLResponseIsAttachment(WKURLResponseRef responseRef)
{
    return toImpl(responseRef)->resourceResponse().isAttachment();
}

uint32_t WKURLResponseGetExpectedContentLength(WKURLResponseRef responseRef)
{
    return toImpl(responseRef)->resourceResponse().expectedContentLength();
}
